@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 use vars qw( $VERSION );
-$VERSION = '0.08';
+$VERSION = '0.10';
 
 use Carp qw( croak );
 use Config::Tiny;
@@ -12,7 +12,8 @@ use base qw( Class::Accessor );
 my @variables = qw(
    dbtype dbname dbuser dbpass dbport dbhost dbencoding
    script_name install_directory script_url
-   custom_lib_path use_plucene use_lucy indexing_directory enable_page_deletion
+   custom_lib_path use_plucene use_lucy search_content_munger_module
+   indexing_directory enable_page_deletion
    admin_pass stylesheet_url site_name navbar_on_home_page
    recent_changes_on_home_page random_page_omits_locales
    random_page_omits_categories content_above_navbar_in_html home_name
@@ -25,8 +26,9 @@ my @variables = qw(
    licence_name licence_url licence_info_url
    moderation_requires_password moderate_whitelist
    enable_node_image enable_common_categories enable_common_locales
-   spam_detector_module host_checker_module static_path static_url
-   send_moderation_notifications website_link_max_chars read_only
+   spam_detector_module host_checker_module custom_macro_module
+   static_path static_url
+   send_moderation_notifications website_link_max_chars read_only responsive
 );
 my @questions = map { $_ . "__qu" } @variables;
 OpenGuides::Config->mk_accessors( @variables );
@@ -79,6 +81,7 @@ sub _init {
                      install_directory => "/usr/lib/cgi-bin/openguides/",
                      use_plucene => 1,
                      use_lucy => 0,
+                     search_content_munger_module => "",
                      indexing_directory => "/usr/lib/cgi-bin/openguides/indexes/",
                      enable_page_deletion => 0,
                      moderation_requires_password => 1,
@@ -117,10 +120,12 @@ sub _init {
                      licence_info_url => "",
                      spam_detector_module => "",
                      host_checker_module => "",
+                     custom_macro_module => "",
                      static_path => "/usr/local/share/openguides/static",
                      send_moderation_notifications => 1,
                      website_link_max_chars => 25,
                      read_only => 0,
+                     responsive => 0,
                    );
 
     # See if we already have some config variables set.
@@ -165,6 +170,7 @@ sub _init {
         custom_lib_path => "Do you want me to munge a custom lib path into the scripts?  If so, enter it here.  Separate path entries with whitespace.",
         use_plucene => "Do you want to use Plucene for searching? (recommended, but see Changes file before saying yes to this if you are upgrading)",
         use_lucy => "Do you want to use Lucy for searching? (experimental)",
+        search_content_munger_module => "What module would you like to use to munge node content before indexing for the search? (optional, only works with Plucene and Lucy)",
         indexing_directory => "What directory can I use to store indexes in for searching? ***NOTE*** This directory must exist and be writeable by the user that your script will run as.  See README for more on this.",
         enable_page_deletion => "Do you want to enable page deletion?",
         moderation_requires_password => "Is the admin password required for moderating pages?",
@@ -205,12 +211,14 @@ sub _init {
         licence_info_url => "What is the URL to your local page about your licensing policy?",
         spam_detector_module => "What module would you like to use for spam detection? (optional)",
         host_checker_module => "What module would you like to use to run an IP blacklist? (optional)",
+        custom_macro_module => "What module would you like to use to define custom macros? (optional)",
         static_path => "What directory should we install static content (CSS, images, javascript) to?",
         static_url => "What is the URL corresponding to the static content?",
         send_moderation_notifications => "Should we send email notifications when a moderated node is edited?",
         website_link_max_chars => "How many characters of the URL of node websites should be displayed?",
         moderate_whitelist => "Enter a comma-separated list of IP addresses able to make changes to moderated nodes and have them show up immediately",
         read_only => "Should the guide be read-only (no edits permitted)?",
+        responsive => "Should the site be mobile-friendly (responsive)?",
     );
 
     foreach my $var ( keys %questions ) {
@@ -271,6 +279,8 @@ sub script_url {
 
 =item * use_lucy (default: false)
 
+=item * search_content_munger_module
+
 =item * indexing_directory (default: C</usr/lib/cgi-bin/openguides/indexes>)
 
 =item * enable_page_deletion (default: false)
@@ -343,6 +353,8 @@ sub script_url {
 
 =item * host_checker_module
 
+=item * custom_macro_module
+
 =item * static_path
 
 =item * static_url (this is constrained to always end in C</>)
@@ -365,6 +377,8 @@ sub static_url {
 
 =item * read_only
 
+=item * responsive
+
 =back
 
 =head1 AUTHOR
