@@ -1,4 +1,4 @@
-var centre_lat, centre_long, min_lat, min_long, max_lat, max_long, map, map_div_id;
+var full_cgi_url, centre_lat, centre_long, min_lat, min_long, max_lat, max_long, map, map_div_id;
 var positions = [], markers = [];
 
 var gicon = L.Icon.extend( {
@@ -16,11 +16,6 @@ $(
     if ( map_div_id && centre_lat && centre_long ) {
       var map_centre = new L.LatLng( centre_lat, centre_long );
 
-      var mq_url = 'http://{s}.mqcdn.com/tiles/1.0.0/osm/{z}/{x}/{y}.png';
-      var subdomains = [ 'otile1', 'otile2', 'otile3', 'otile4' ];
-      var attrib = 'Data, imagery and map information provided by <a href="http://open.mapquest.co.uk" target="_blank">MapQuest</a>, <a href="http://www.openstreetmap.org/" target="_blank">OpenStreetMap</a> and contributors, <a href="http://creativecommons.org/licenses/by-sa/2.0/" target="_blank">CC-BY-SA</a>';
-      var mapquest_layer = new L.TileLayer( mq_url, { maxZoom: 18, attribution: attrib, subdomains: subdomains } );
-
       var osm_layer = new L.TileLayer(
           'http://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png' );
 
@@ -39,12 +34,6 @@ $(
         map.fitBounds( bounds );
       }
 
-      var layersControl = new L.Control.Layers( {
-        "MapQuest": mapquest_layer,
-        "OpenStreetMap": osm_layer,
-      } );
-      map.addControl( layersControl );
-
       L.control.scale().addTo(map);
 
       add_markers();
@@ -65,7 +54,7 @@ function add_marker( i, node ) {
   marker = new L.Marker( position, { icon: new gicon() } );
   map.addLayer( marker );
 
-  content = '<a href="?' + node.param + '">' + node.name + '</a>';
+  content = '<a href="' + full_cgi_url + '?' + node.param + '">' + node.name + '</a>';
   if ( node.address ) {
     content += '<br />' + node.address;
   }
